summaryrefslogtreecommitdiff
path: root/fluid/Fl_Function_Type.cxx
diff options
context:
space:
mode:
authorAlbrecht Schlosser <albrechts.fltk@online.de>2015-03-09 20:37:45 +0000
committerAlbrecht Schlosser <albrechts.fltk@online.de>2015-03-09 20:37:45 +0000
commitc96c4c35b0c308c1da9796ca88762044851d3801 (patch)
treeae6eb8a6fee1f1f8ba582548fc9eb41e7271fe1f /fluid/Fl_Function_Type.cxx
parentc9ff10d8f9ad238cdc984dd820616f0335279cfb (diff)
Add 'fluid -u' command-line switch to upgrade fluid files in batch mode.
This option opens a fluid ('.fl') file and saves it overwriting the old file with the current syntax and library version number. git-svn-id: file:///fltk/svn/fltk/branches/branch-1.3@10611 ea41ed52-d2ee-0310-a9c1-e6b18d33e121
Diffstat (limited to 'fluid/Fl_Function_Type.cxx')
-rw-r--r--fluid/Fl_Function_Type.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/fluid/Fl_Function_Type.cxx b/fluid/Fl_Function_Type.cxx
index a6991a6f8..5ca6c192c 100644
--- a/fluid/Fl_Function_Type.cxx
+++ b/fluid/Fl_Function_Type.cxx
@@ -33,7 +33,7 @@ extern const char* i18n_file;
extern const char* i18n_set;
extern char i18n_program[];
-extern int compile_only;
+extern int batch_mode;
extern void redraw_browser();
extern void goto_source_dir();
@@ -920,9 +920,9 @@ void Fl_Data_Type::write_code1() {
}
}
// if we are in interactive mode, we pop up a warning dialog
// giving the error: (compile_only && !write_sourceview)
if (message && !write_sourceview) {
- if (compile_only)
+ if (batch_mode)
fprintf(stderr, "FLUID ERROR: %s %s\n", message, fn);
else
fl_alert("%s\n%s\n", message, fn);
@@ -920,9 +920,9 @@ void Fl_Data_Type::write_code1() {
}
// if we are in interactive mode, we pop up a warning dialog
- // giving the error: (compile_only && !write_sourceview)
+ // giving the error: (batch_mode && !write_sourceview) ???
if (message && !write_sourceview) {